@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.808.2.2 2020/04/15 13:14:02 bket Exp $
+# $OpenBSD: Quirks.pm,v 1.808.2.3 2020/04/22 02:12:16 jca Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -1469,6 +1469,7 @@ my $cve = {
 	'net/lldpd' => 'lldpd-<0.7.18p0',
 	'net/mosquitto' => 'mosquitto-<1.5.6',
 	'net/ntp' => 'ntp-<4.2.8pl7',
+	'net/openvpn' => 'openvpn-<2.4.7p2',
 	'net/openconnect' => 'openconnect-<8.05',
 	'net/powerdns,-main' => 'powerdns-<4.1.5',
 	'net/powerdns,-mysql' => 'powerdns-mysql-<4.1.5',
